-- use Tier labels instead of numbers
-- use per tier categories... this may be problematic
-- sort categories alphabetically
-- sort recipes alphabetically within categories - this will fix the ordering issue when adding new recipes
-- some recipes are still showing as duplicates like the scholar supreme level LI recipes

euroFormat=(tonumber("1,000")==1); -- redundant but harmless
import "GaranStuff.AltInventory.Crafting"

function LoadData()
	-- load saved settings
	KnownRecipes=PatchDataLoad( Turbine.DataScope.Server, "AltInventory_RecipeData");
	if KnownRecipes==nil then
		KnownRecipes={};
	end
end
LoadData()

CraftingPanel=class(Turbine.UI.Control)
function CraftingPanel:Constructor()
	Turbine.UI.Control.Constructor(self)
	self:SetMouseVisible(false);
	self:SetBackColor(backColor);
	self:SetSize(200,200);
	self.characterIndex=1;
	local charIndex;
	for charIndex=1,#characterListArray do
		if characterListArray[charIndex][1]==currentCharacterName then
			self.characterIndex=charIndex;
			break;
		end
	end
	self.characterName=currentCharacterName;
	self.VocationCaption=Turbine.UI.Label();
	self.VocationCaption:SetParent(self);
	self.VocationCaption:SetSize(100,20);
	self.VocationCaption:SetPosition(5,5);
	self.VocationCaption:SetForeColor(fontColor);
	self.VocationCaption:SetFont(Turbine.UI.Lotro.Font.Verdana14);
	self.VocationCaption:SetText(Resource[language][315]..":");

	self.VocationList=DropDownList();
	self.VocationList:SetParent(self);
	self.VocationList:SetSize(100,18);
	self.VocationList:SetPosition(100,5);
	self.VocationList:SetFont(Turbine.UI.Lotro.Font.Verdana14);
	self.VocationList:SetDropRows(10);
	self.VocationList:SetBorderColor(trimColor);
	self.VocationList:SetBackColor(backColor);
	self.VocationList:SetTextColor(listTextColor);
	self.VocationList:SetCurrentBackColor(backColor);
	self.VocationList:SetZOrder(self.VocationList:GetZOrder()+2);


	self.VocationList:SetSelectedIndex(1);
	self.VocationList.SelectedIndexChanged=function(sender)
		local tmpIndex;
		for tmpIndex=1,3 do
			self.ProfessionButtons[tmpIndex]:SetText(Resource[language][Profession[Vocation[self.VocationList:GetSelectedIndex()]["Profession"..tostring(tmpIndex)]][2]]);
			self.ProfessionButtons[tmpIndex].Profession=Vocation[self.VocationList:GetSelectedIndex()]["Profession"..tostring(tmpIndex)];
		end
		self.SelectedProfession=Vocation[self.VocationList:GetSelectedIndex()]["Profession"..tostring(self.SelectedButton)];
		characterListArray[self.characterIndex][10]=self.VocationList:GetSelectedIndex();
		self.RefreshRecipeTree();
	end

	local tmpIndex;
	for tmpIndex=1,#Vocation do
		self.VocationList:AddItem(Resource[language][Vocation[tmpIndex]["Name"][2]],vocIndex);
	end

	self.ProfessionButtons={}
	for tmpIndex=1,3 do
		self.ProfessionButtons[tmpIndex]=Turbine.UI.Lotro.Button();
		self.ProfessionButtons[tmpIndex]:SetParent(self);
		self.ProfessionButtons[tmpIndex]:SetSize(120,20);
		self.ProfessionButtons[tmpIndex]:SetPosition(100*(tmpIndex-1),30);
		self.ProfessionButtons[tmpIndex]:SetFont(Turbine.UI.Lotro.Font.Verdana14);
		self.ProfessionButtons[tmpIndex]:SetText(Resource[language][Profession[Vocation[self.VocationList:GetSelectedIndex()]["Profession"..tostring(tmpIndex)]][2]]);
		self.ProfessionButtons[tmpIndex].Profession=Vocation[self.VocationList:GetSelectedIndex()]["Profession"..tostring(tmpIndex)];
		self.ProfessionButtons[tmpIndex]:SetForeColor(Turbine.UI.Color(.5,.5,.5));
		self.ProfessionButtons[tmpIndex].Index=tmpIndex;
		self.ProfessionButtons[tmpIndex].MouseClick=function(sender,args)
			local btnIndex
			for btnIndex=1,3 do
				if btnIndex==sender.Index then
					self.ProfessionButtons[btnIndex]:SetForeColor(Turbine.UI.Color(.75,.7,0));
				else
					self.ProfessionButtons[btnIndex]:SetForeColor(Turbine.UI.Color(.5,.5,.5));
				end
			end
			self.SelectedButton=sender.Index;
			self.SelectedProfession=Vocation[self.VocationList:GetSelectedIndex()]["Profession"..tostring(sender.Index)];
			self.RefreshRecipeTree();
		end
	end
	self.SelectedButton=1;
	self.SelectedProfession=Vocation[self.VocationList:GetSelectedIndex()]["Profession1"];
	self.ProfessionButtons[1]:SetForeColor(Turbine.UI.Color(.75,.7,0));

-- search - on text change, hide any recipes that don't have the text in their name
	self.SearchCaption=Turbine.UI.Label();
	self.SearchCaption:SetParent(self);
	self.SearchCaption:SetSize(100,20);
	self.SearchCaption:SetPosition(5,55);
	self.SearchCaption:SetForeColor(fontColor);
	self.SearchCaption:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
	self.SearchCaption:SetFont(Turbine.UI.Lotro.Font.Verdana14);
	self.SearchCaption:SetText(Resource[language][25]..":");

	self.SearchText=Turbine.UI.Lotro.TextBox();
	self.SearchText:SetParent(self);
	self.SearchText:SetPosition(101,self.SearchCaption:GetTop());
	self.SearchText:SetBackColor(Turbine.UI.Color(.25,.35,.55));
	self.SearchText:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
	self.SearchText:SetFont(Turbine.UI.Lotro.Font.Verdana14);
	self.SearchText:SetForeColor(fontColor);
	self.SearchText:SetOutlineColor(Turbine.UI.Color(0,0,0));
	self.SearchText:SetFontStyle(Turbine.UI.FontStyle.Outline);
	self.SearchText:SetWantsUpdates(false);
	self.SearchText.Text="";
	self.SearchText.FocusGained=function()
		self.SearchText:SetWantsUpdates(true);
	end
	self.SearchText.FocusLost=function()
		self.SearchText:SetWantsUpdates(false);
	end
	self.SearchText.Update=function()
		if self.SearchText:GetText()~=self.SearchText.Text then
			self.SearchText.Text=self.SearchText:GetText();
			self:RecipesRefresh();
		end
	end

-- filter - any, unlimited, one shots
	self.FilterCaption=Turbine.UI.Label();
	self.FilterCaption:SetParent(self);
	self.FilterCaption:SetSize(100,20);
	self.FilterCaption:SetPosition(5,80);
	self.FilterCaption:SetForeColor(fontColor);
	self.FilterCaption:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
	self.FilterCaption:SetFont(Turbine.UI.Lotro.Font.Verdana14);
	self.FilterCaption:SetText(Resource[language][24]..":");

	self.Filter=RadioButtonGroup();
	self.Filter:SetParent(self);
	self.Filter:SetPosition(100,self.FilterCaption:GetTop());
	self.Filter:SetSize(100,20);
	self.Filter.UnselectedIcon="GaranStuff/AltInventory/Resources/RB_unselected.tga";
	self.Filter.SelectedIcon="GaranStuff/AltInventory/Resources/RB_selected.tga";
	self.Filter.IconWidth=16;
	self.Filter.IconHeight=16;
	self.Filter:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.Filter:SetBorderColor(backColor);
	self.Filter:SetBackColor(backColor);
	self.Filter:SetTextColor(fontColor);
	self.Filter:AddChoice(Resource[language][29]);
	self.Filter:AddChoice(Resource[language][337]);
	self.Filter:AddChoice(Resource[language][338]);
	self.Filter:SetRows(1);
	self.Filter:SetSelectedChoice(1);
	self.Filter.SelectionChanged=function()
		self:RecipesRefresh();
	end

	self.RecipesRefresh=function()
		local searchText=string.lower(self.SearchText:GetText());
		local tier,recipe
		for tier=1,self.RecipePanel:GetNodes():GetCount() do
			local tierNode=self.RecipePanel:GetNodes():Get(tier);
			for category=1,tierNode:GetChildNodes():GetCount() do
				local categoryNode=tierNode:GetChildNodes():Get(category);
				for recipe=1,categoryNode:GetChildNodes():GetCount() do
					local recipeNode=categoryNode:GetChildNodes():Get(recipe);
					if searchText==nil or string.find(string.lower(recipeNode.Text:GetText()),searchText)~=nil then
						-- apply the Filter if it is set
						if self.Filter:GetSelectedChoice()==1 then
							recipeNode:SetHeight(20);
						elseif self.Filter:GetSelectedChoice()==2 then
							if recipeNode.OneShot then
								recipeNode:SetHeight(0);
							else
								recipeNode:SetHeight(20);
							end
						else
							if recipeNode.OneShot then
								recipeNode:SetHeight(20);
							else
								recipeNode:SetHeight(0);
							end
						end
					else
						recipeNode:SetHeight(0);
					end
				end
			end
		end
	end

	self.ExpandAll=Turbine.UI.Control();
	self.ExpandAll:SetParent(self);
	self.ExpandAll:SetSize(16,16);
	self.ExpandAll:SetPosition(5,107);
	self.ExpandAll:SetBackground(0x4100027b); -- 0x4100027a,0x4100027b,0x4100027c
	self.ExpandAll:SetBlendMode(Turbine.UI.BlendMode.Overlay)
	self.ExpandAll.MouseEnter=function()
		self.ExpandAll:SetBackground(0x4100027c);
	end
	self.ExpandAll.MouseLeave=function()
		self.ExpandAll:SetBackground(0x4100027b);
	end
	self.ExpandAll.MouseDown=function()
		self.ExpandAll:SetBackground(0x4100027a);
	end
	self.ExpandAll.MouseUp=function()
		self.ExpandAll:SetBackground(0x4100027c);
	end
	self.ExpandAll.MouseClick=function()
		local tier
		for tier=1,self.RecipePanel:GetNodes():GetCount() do
			local tierNode=self.RecipePanel:GetNodes():Get(tier);
			tierNode:SetExpanded(true);
			tierNode.Collapse:SetBackground(0x41007e26);
			for tmpCategory=1,tierNode:GetChildNodes():GetCount() do
				local categoryNode=tierNode:GetChildNodes():Get(tmpCategory);
				categoryNode:SetExpanded(true);
				categoryNode.Collapse:SetBackground(0x41007e26);
			end
		end
	end

	self.CollapseAll=Turbine.UI.Control();
	self.CollapseAll:SetParent(self);
	self.CollapseAll:SetSize(16,16);
	self.CollapseAll:SetPosition(25,107);
	self.CollapseAll:SetBlendMode(Turbine.UI.BlendMode.Overlay)
	self.CollapseAll:SetBackground(0x4100027e); -- 0x4100027d,0x4100027e,0x4100027f
	self.CollapseAll.MouseEnter=function()
		self.CollapseAll:SetBackground(0x4100027f);
	end
	self.CollapseAll.MouseLeave=function()
		self.CollapseAll:SetBackground(0x4100027e);
	end
	self.CollapseAll.MouseDown=function()
		self.CollapseAll:SetBackground(0x4100027d);
	end
	self.CollapseAll.MouseUp=function()
		self.CollapseAll:SetBackground(0x4100027f);
	end
	self.CollapseAll.MouseClick=function()
		local tier
		for tier=1,self.RecipePanel:GetNodes():GetCount() do
			local tierNode=self.RecipePanel:GetNodes():Get(tier);
			tierNode:SetExpanded(false);
			tierNode.Collapse:SetBackground(0x41007e27);
			for tmpCategory=1,tierNode:GetChildNodes():GetCount() do
				local categoryNode=tierNode:GetChildNodes():Get(tmpCategory);
				categoryNode:SetExpanded(false);
				categoryNode.Collapse:SetBackground(0x41007e27);
			end
		end
	end

	self.RecipePanel=Turbine.UI.TreeView();
	self.RecipePanel:SetParent(self);
	self.RecipePanel:SetSize(200,200);
	self.RecipePanel:SetPosition(5,130);
	self.RecipePanel:SetBackColor(backColor);
	self.RecipeVScroll=Turbine.UI.Lotro.ScrollBar();
	self.RecipeVScroll:SetOrientation(Turbine.UI.Orientation.Vertical);
	self.RecipeVScroll:SetParent(self);
	self.RecipeVScroll:SetBackColor(backColor);
	self.RecipeVScroll:SetPosition(self.RecipePanel:GetWidth()+5,130);
	self.RecipeVScroll:SetWidth(12);
	self.RecipeVScroll:SetHeight(200);
	self.RecipePanel:SetVerticalScrollBar(self.RecipeVScroll);

	self.RefreshRecipeTree=function()
		local tmpTier;
		local tmpCategory;
		local tmpRecipe;
		local nodeList=self.RecipePanel:GetNodes();
		local width=self.RecipePanel:GetWidth();
		if width<100 then width=100 end
		nodeList:Clear();
		for tmpTier=1,#Recipe[self.SelectedProfession] do
			local tierNode=Turbine.UI.TreeNode();
			tierNode:SetParent(self.RecipePanel);
			tierNode:SetSize(width,20);
			tierNode.Collapse=Turbine.UI.Control();
			tierNode.Collapse:SetParent(tierNode);
			tierNode.Collapse:SetSize(16,16);
			tierNode.Collapse:SetPosition(0,2);
			tierNode.Collapse:SetBlendMode(Turbine.UI.BlendMode.Overlay);
			tierNode.Collapse:SetBackground(0x41007e27);
			tierNode.Collapse:SetMouseVisible(false);
			tierNode.Text=Turbine.UI.Label();
			tierNode.Text:SetParent(tierNode);
			tierNode.Text:SetSize(width-18,20);
			tierNode.Text:SetPosition(18,0);
			tierNode.Text:SetFont(Turbine.UI.Lotro.Font.TrajanPro16)
			tierNode.Text:SetForeColor(headingsColor);
			tierNode.Text:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft);
			tierNode.Text:SetText(Resource[language][Tier[tmpTier][2]]);
			tierNode.Text:SetMouseVisible(false);

			tierNode.SelectAll=Turbine.UI.Lotro.Button();
			tierNode.SelectAll:SetParent(tierNode);
			tierNode.SelectAll:SetSize(100,20);
			tierNode.SelectAll:SetPosition(118,0);
			tierNode.SelectAll:SetFont(Turbine.UI.Lotro.Font.Verdana12);
			tierNode.SelectAll:SetText(Resource[language][324]);
			tierNode.SelectAll.MouseClick=function(sender,args)
				local node=sender:GetParent();
				node:SetExpanded(not node:IsExpanded()); -- override the built in expand/collapse
				-- we need to iterate through all of the category nodes
				local category,catNode;
				for category=1,node:GetChildNodes():GetCount() do
					catNode=node:GetChildNodes():Get(category);
					local recipe;
					for recipe=1,catNode:GetChildNodes():GetCount() do
						local recipeNode=catNode:GetChildNodes():Get(recipe);
						if not recipeNode.Auto then
							recipeNode.Text:SetChecked(true);
						end
					end
				end
			end
			tierNode.ClearAll=Turbine.UI.Lotro.Button();
			tierNode.ClearAll:SetParent(tierNode);
			tierNode.ClearAll:SetSize(100,20);
			tierNode.ClearAll:SetPosition(223,0);
			tierNode.ClearAll:SetFont(Turbine.UI.Lotro.Font.Verdana12);
			tierNode.ClearAll:SetText(Resource[language][325]);
			tierNode.ClearAll.MouseClick=function(sender,args)
				local node=sender:GetParent();
				node:SetExpanded(not node:IsExpanded()); -- override the built in expand/collapse

				-- we need to iterate through all of the category nodes
				local category,catNode;
				for category=1,node:GetChildNodes():GetCount() do
					catNode=node:GetChildNodes():Get(category);
					local recipe;
					for recipe=1,catNode:GetChildNodes():GetCount() do
						local recipeNode=catNode:GetChildNodes():Get(recipe);
						if not recipeNode.Auto then
							recipeNode.Text:SetChecked(false);
						end
					end
				end
			end

			tierNode.MouseClick=function(sender,args)
				if sender:IsExpanded() then
					sender.Collapse:SetBackground(0x41007e26);
				else
					sender.Collapse:SetBackground(0x41007e27);
				end
			end

			nodeList:Add(tierNode);
			
			for tmpCategory=1,#Recipe[self.SelectedProfession][tmpTier] do
				local categoryNode=Turbine.UI.TreeNode();
				categoryNode:SetParent(self.RecipePanel);
				categoryNode:SetSize(width,20);
				categoryNode.Collapse=Turbine.UI.Control();
				categoryNode.Collapse:SetParent(categoryNode);
				categoryNode.Collapse:SetSize(16,16);
				categoryNode.Collapse:SetPosition(18,2);
				categoryNode.Collapse:SetBlendMode(Turbine.UI.BlendMode.Overlay);
				categoryNode.Collapse:SetBackground(0x41007e27);
				categoryNode.Collapse:SetMouseVisible(false);
				categoryNode.Text=Turbine.UI.Label();
				categoryNode.Text:SetParent(categoryNode);
				categoryNode.Text:SetSize(width-36,20);
				categoryNode.Text:SetPosition(36,0);
				categoryNode.Text:SetFont(Turbine.UI.Lotro.Font.TrajanPro16)
				categoryNode.Text:SetForeColor(fontColor);
				categoryNode.Text:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft);
--Turbine.Shell.WriteLine("tmpTier:"..tostring(tmpTier).." tmpCategory:"..tostring(tmpCategory))
				categoryNode.Text:SetText(CraftStr[language][Categories[self.SelectedProfession][tmpTier][tmpCategory]]);
				categoryNode.Text:SetMouseVisible(false);

				categoryNode.MouseClick=function(sender,args)
					if sender:IsExpanded() then
						sender.Collapse:SetBackground(0x41007e26);
					else
						sender.Collapse:SetBackground(0x41007e27);
					end
				end

				tierNode:GetChildNodes():Add(categoryNode);

				for tmpRecipe=1,#Recipe[self.SelectedProfession][tmpTier][tmpCategory] do
					local recipeNode=Turbine.UI.TreeNode();
					local auto=Recipe[self.SelectedProfession][tmpTier][tmpCategory][tmpRecipe][4]; -- this data is not currently valid, all recipes are set to false

					recipeNode:SetParent(self.RecipePanel);
					recipeNode:SetSize(width,20);
					if auto then
						recipeNode.Text=Turbine.UI.Label();
						recipeNode.Text:SetSize(width-52,20);
						recipeNode.Text:SetPosition(52,0);
					else
						recipeNode.Text=Turbine.UI.Lotro.CheckBox();
						recipeNode.Text:SetSize(width-36,20);
						recipeNode.Text:SetPosition(36,0);
					end
					recipeNode.Text:SetParent(recipeNode);
					recipeNode.Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
					recipeNode.Text:SetText(Recipe[self.SelectedProfession][tmpTier][tmpCategory][tmpRecipe][2]);
					recipeNode.Text.RecipeID=Recipe[self.SelectedProfession][tmpTier][tmpCategory][tmpRecipe][1]
					recipeNode.OneShot=Recipe[self.SelectedProfession][tmpTier][tmpCategory][tmpRecipe][3];
					recipeNode.Auto=auto;
					recipeNode.Text.Tier=tmpTier;
					recipeNode.Text.Recipe=tmpRecipe;
					if KnownRecipes[self.characterName]==nil then KnownRecipes[self.characterName]={} end
					if auto then
						KnownRecipes[self.characterName][recipeNode.Text.RecipeID]=true;
					else
						if KnownRecipes[self.characterName][recipeNode.Text.RecipeID]==nil then
							KnownRecipes[self.characterName][recipeNode.Text.RecipeID]=false;
						else
							recipeNode.Text:SetChecked(KnownRecipes[self.characterName][recipeNode.Text.RecipeID]);
						end
					end
					if not auto then
						recipeNode.Text.CheckedChanged=function(sender)
							if KnownRecipes[self.characterName]==nil then KnownRecipes[self.characterName]={} end
							KnownRecipes[self.characterName][sender.RecipeID]=sender:IsChecked();
						end
					end
					categoryNode:GetChildNodes():Add(recipeNode);
				end
			end
		end
		self:RecipesRefresh();
	end

	self.RefreshRecipeTree();

	self:SetVisible(false);

	self.LoadPanelData=function(sender, characterName)
		self.characterName=characterName;
		-- routine to set the recipe lists and known recipes for the selected character

		local tmpIndex;
		for tmpIndex=1,#characterListArray do
			if characterListArray[tmpIndex][1]==characterName then
				self.characterIndex=tmpIndex;
				local vocation=characterListArray[tmpIndex][10];
				if vocation~=nil and vocation>0 and vocation<=self.VocationList.ListData:GetItemCount() then
					self.VocationList:SetSelectedIndex(vocation);
					self.VocationList.SelectedIndexChanged()
				end
				-- make window non-visible if alignment~=free people
				if inventoryWindow~=nil and inventoryWindow.PanelShowing==self.Index then
					self:SetVisible(self:IsValid())
				end
				-- now we need to loop through the KnownRecipes for this character and flag all of those that are known
				break;
			end
		end		
	end

	self.IsValid=function()
		return (characterListArray[self.characterIndex][9]==Turbine.Gameplay.Alignment.FreePeople)
	end

	self.SaveData=function()
		PatchDataSave( Turbine.DataScope.Server, "AltInventory_RecipeData",KnownRecipes);
	end
	self.RemoveCallbacks=function()
	end
	self.SizeChanged=function(sender,args)
		local newWidth=self:GetWidth();
		local newHeight=self:GetHeight();
		self.VocationList:SetWidth(newWidth-self.VocationList:GetLeft()-5);
		self.SearchText:SetSize(newWidth-self.SearchText:GetLeft()-6,20);
		self.Filter:SetSize(newWidth-self.Filter:GetLeft()-5,20);
		self.Filter:Layout();
		local space=(newWidth-self.ProfessionButtons[1]:GetWidth()*3)/4;
		local btnIndex;
		for btnIndex=1,3 do
			self.ProfessionButtons[btnIndex]:SetLeft((space+self.ProfessionButtons[1]:GetWidth())*(btnIndex-1)+space);
		end
		self.RecipePanel:SetSize(newWidth-22,self:GetHeight()-self.RecipePanel:GetTop()-5);
		self.RecipeVScroll:SetLeft(self.RecipePanel:GetLeft()+self.RecipePanel:GetWidth());
		self.RecipeVScroll:SetHeight(self.RecipePanel:GetHeight());
		local tier,recipe
		for tier=1,self.RecipePanel:GetNodes():GetCount() do
			local tierNode=self.RecipePanel:GetNodes():Get(tier);
			tierNode:SetWidth(newWidth-22);
			tierNode.Text:SetWidth(newWidth-40);
			for category=1,tierNode:GetChildNodes():GetCount() do
				local categoryNode=tierNode:GetChildNodes():Get(category);
				categoryNode:SetWidth(newWidth-22);
				categoryNode.Text:SetWidth(newWidth-40);
				for recipe=1,categoryNode:GetChildNodes():GetCount() do
					local recipeNode=categoryNode:GetChildNodes():Get(recipe);
					recipeNode:SetWidth(newWidth-22);
					recipeNode.Text:SetWidth(newWidth-58);
				end
			end
		end
	end
	self.SetLanguage=function()
		self.VocationCaption:SetText(Resource[language][315]..":");
		self.SearchCaption:SetText(Resource[language][25]..":");
		self.FilterCaption:SetText(Resource[language][24]..":");
		local vocIndex;
		for vocIndex=1,#Vocation do
			self.VocationList.ListData:GetItem(vocIndex):SetText(Resource[language][Vocation[vocIndex]["Name"][2]]);
		end
		if self.VocationList:GetSelectedIndex()>0 then
			self.VocationList.CurrentValue:SetText(Resource[language][Vocation[self.VocationList:GetSelectedIndex()]["Name"][2]])
		end
		local tmpIndex;
		for tmpIndex=1,3 do
			self.ProfessionButtons[tmpIndex]:SetText(Resource[language][Profession[Vocation[self.VocationList:GetSelectedIndex()]["Profession"..tostring(tmpIndex)]][2]]);
		end
		
		local tier
		for tier=1,self.RecipePanel:GetNodes():GetCount() do
			local tierNode=self.RecipePanel:GetNodes():Get(tier).Text:SetText(Resource[language][Tier[tier][2]]);
			if tierNode~=nil then
				for tmpCategory=1,tierNode:GetChildNodes():GetCount() do
					tierNode:GetChildNodes():Get(tmpCategory).Text:SetText(CraftStr[language][Categories[self.SelectedProfession][tier][tmpCategory]]);
				end
			end
		end
		self.Filter.Choices[1].Caption:SetText(Resource[language][29]);
		self.Filter.Choices[2].Caption:SetText(Resource[language][337]);
		self.Filter.Choices[3].Caption:SetText(Resource[language][338]);

	end
	self.SetTrimColor=function()
		-- reassign the trimColor
		self.VocationList:SetBorderColor(trimColor);
	end
	self.SetBackgroundColor=function()
		-- reassign the backColor
		self.VocationList:SetBackColor(backColor);
		self.VocationList:SetCurrentBackColor(backColor);
	end
	self.SetListTextColor=function()
		-- reassign the listTextColor
		self.VocationList:SetTextColor(listTextColor);
	end
	self.SetFontColor=function()
		-- reassign the fontColor
		self.VocationCaption:SetForeColor(fontColor);
		self.SearchCaption:SetForeColor(fontColor);
		self.FilterCaption:SetForeColor(fontColor);
	end
	self.SetHeadingsColor=function()
		-- reassign the backColor
		local tier
		for tier=1,self.RecipePanel:GetNodes():GetCount() do
			local tierNode=self.RecipePanel:GetNodes():Get(tier).Text:SetForeColor(headingsColor);
		end
	end
end
